package config

type Config struct {
	Log       Log         `mapstructure:"log" json:"log" yaml:"log"`
	Serve     Serve       `mapstructure:"serve" json:"serve" yaml:"serve"`
	Email     Email       `mapstructure:"email" json:"email" yaml:"email"`
	SqLite    SqLite      `mapstructure:"sqlite" json:"sqlite" yaml:"sqlite"`
	EmailRule []EmailRule `mapstructure:"email-rule" json:"email-rule" yaml:"email-rule" description:"邮件规则"`
}

type SqLite struct {
	Stdout bool   `mapstructure:"stdout" json:"stdout" yaml:"stdout" description:"日志是否输出在控制台"`
	DbPath string `mapstructure:"db-path" json:"db-path" yaml:"db-path" description:"sqlite数据库路径"`
}

type EmailRule struct {
	Pattern        string `mapstructure:"pattern" json:"pattern" yaml:"pattern" description:"正则表达式"`
	From           string `mapstructure:"from" json:"from" yaml:"from" description:"发件人"`
	Type           int    `mapstructure:"type" json:"type" yaml:"type" description:"规则类型:1-报告"`
	Source         string `mapstructure:"source" json:"source" yaml:"source" description:"规则来源"`
	ClassifyPath   string `mapstructure:"classify-path" json:"classify-path" yaml:"classify-path" description:"分类路径, 使用/分割"`
	FilterFileType string `mapstructure:"filter-file-type" json:"filter-file-type" yaml:"filter-file-type" description:"过滤文件类型"`
}

// Serve gin服务配置
type Serve struct {
	Port       int    `mapstructure:"port" json:"port" yaml:"port" description:"gin开启监听http服务的端口"`
	RunMode    string `mapstructure:"run-mode" json:"run-mode" yaml:"run-mode" description:"gin运行模式的默认，枚举值：debug,release"`
	UseRedis   bool   `mapstructure:"use-redis" json:"use-redis" yaml:"use-redis" description:"是否使用redis"`
	AppName    string `mapstructure:"app-name" json:"app-name" yaml:"app-name" description:"项目名称"`
	StaticDir  string `mapstructure:"static-dir" json:"static-dir" yaml:"static-dir" description:"上传的文件存储目录地址"`
	AppNameEn  string `mapstructure:"app-name-en" json:"app-name-en" yaml:"app-name-en" description:"项目名称英文"`
	Md5Key     string `mapstructure:"md5-key" json:"md5-key" yaml:"md5-key" description:"Md5密钥"`
	DesKey     string `mapstructure:"des-key" json:"des-key" yaml:"des-key" description:"Des密钥"`
	IsStopTask bool   `mapstructure:"is-stop-task" json:"is-stop-task" yaml:"is-stop-task" description:"是否停止任务，此功能用于多服务器部署时，定时任务只需一台服务器执行，其他服务器不执行的情况下设置为true"`
	BridgeUrl  string `mapstructure:"bridge-url" json:"bridge-url" yaml:"bridge-url" description:"bridge服务地址"`
	BridgeMD5  string `mapstructure:"bridge-md5" json:"bridge-md5" yaml:"bridge-md5" description:"bridge服务md5密钥"`
	BridgeDes  string `mapstructure:"bridge-des" json:"bridge-des" yaml:"bridge-des" description:"bridge服务des密钥"`
}

// Log 日志配置
type Log struct {
	Prefix          string `mapstructure:"prefix" json:"prefix" yaml:"prefix" description:"日志输出前缀"`
	LogFile         bool   `mapstructure:"log-file" json:"logFile" yaml:"log-file" description:""`
	Stdout          string `mapstructure:"stdout" json:"stdout" yaml:"stdout" description:""`
	FileStdout      string `mapstructure:"file-stdout" json:"file-stdout" yaml:"file-stdout" description:""`
	SaveMaxDay      int    `mapstructure:"save-max-day" json:"save-max-day" yaml:"save-max-day" description:"最多保留多少天的日志"`
	CuttingDay      int    `mapstructure:"cutting-day" json:"cutting-day" yaml:"cutting-day" description:"相隔几天切割文件"`
	LogDirPath      string `mapstructure:"log-dir-path" json:"log-dir-path" yaml:"log-dir-path" description:"日志目录"`
	LogSoftLink     string `mapstructure:"log-soft-link" json:"log-soft-link" yaml:"log-soft-link" description:"日志软链接"`
	BinlogDirPath   string `mapstructure:"binlog-dir-path" json:"binlog-dir-path" yaml:"binlog-dir-path" description:"binlog日志目录"`
	BinlogSoftLink  string `mapstructure:"binlog-soft-link" json:"binlog-soft-link" yaml:"binlog-soft-link" description:"binlog日志软链接"`
	FilelogDirPath  string `mapstructure:"filelog-dir-path" json:"filelog-dir-path" yaml:"filelog-dir-path" description:"用户自主记录的日志目录"`
	FilelogSoftLink string `mapstructure:"filelog-soft-link" json:"filelog-soft-link" yaml:"filelog-soft-link" description:"用户自主记录的日志软链接"`
}

type Email struct {
	Host                            string   `mapstructure:"host" json:"host" yaml:"host" description:"邮件服务器"`
	Schema                          string   `mapstructure:"schema" json:"schema" yaml:"schema" description:"邮件服务器协议"`
	Port                            int      `mapstructure:"port" json:"port" yaml:"port" description:"邮件服务器端口"`
	UserName                        string   `mapstructure:"username" json:"username" yaml:"username" description:"邮件服务器用户名"`
	Password                        string   `mapstructure:"password" json:"password" yaml:"password" description:"邮件服务器密码"`
	Folder                          string   `mapstructure:"folder" json:"folder" yaml:"folder" description:"邮件服务器文件夹"`
	ReadBatchSize                   int      `mapstructure:"read-batch-size" json:"read-batch-size" yaml:"read-batch-size" description:"邮件读取批次"`
	StartReadIndex                  int      `mapstructure:"start-read-index" json:"start-read-index" yaml:"start-read-index" description:"邮件开始读取的序号"`
	SyncEmailTime                   string   `mapstructure:"sync-email-time" json:"sync-email-time" yaml:"sync-email-time" description:"邮件同步时间"`
	EarlyStop                       bool     `mapstructure:"early-stop" json:"early-stop" yaml:"early-stop" description:"邮件同步提前停止"`
	IgnoreEmail                     []string `mapstructure:"ignore-email" json:"ignore-email" yaml:"ignore-email" description:"邮件过滤，不读取这些邮箱"`
	IgnoreEmailCaseSensitive        []string `mapstructure:"ignore-email-case-sensitive" json:"ignore-email-case-sensitive" yaml:"ignore-email-case-sensitive" description:"邮件过滤，不读取这些邮箱，大小写敏感"`
	IgnoreEmailAddress              []string `mapstructure:"ignore-email-address" json:"ignore-email-address" yaml:"ignore-email-address" description:"邮件过滤，不读取这些邮箱，大小写敏感"`
	IgnoreEmailAddressCaseSensitive []string `mapstructure:"ignore-email-address-case-sensitive" json:"ignore-email-address-case-sensitive" yaml:"ignore-email-address-case-sensitive" description:"邮件过滤，不读取这些邮箱，大小写敏感"`
	IgnoreEmailTitle                []string `mapstructure:"ignore-email-title" json:"ignore-email-title" yaml:"ignore-email-title" description:"邮件过滤，不读取这些标题"`
	IgnoreEmailTitleCaseSensitive   []string `mapstructure:"ignore-email-title-case-sensitive" json:"ignore-email-title-case-sensitive" yaml:"ignore-email-title-case-sensitive" description:"邮件过滤，不读取这些标题，大小写敏感"`
}
