package init_serve

import (
	"gn/gn_email_listen/global"
	"gn/gn_email_listen/models/report"
	"io"
	"log"
	"os"
	"time"

	"gorm.io/driver/sqlite"
	"gorm.io/gorm"
	"gorm.io/gorm/logger"
)

func InitSqlite() {
	// TODO: init sqlite
	sqliteConf := global.CONFIG.SqLite
	//开启日志
	logWriter := io.MultiWriter(global.Sqlite_LOG) //binlog日志，记录到文件中去
	if global.CONFIG.SqLite.Stdout {
		logWriter = io.MultiWriter(global.Sqlite_LOG, os.Stdout)
	}
	newLogger := logger.New(log.New(logWriter, "\r\n", log.LstdFlags), logger.Config{
		SlowThreshold:             200 * time.Millisecond, //慢sql ：200ms
		LogLevel:                  logger.Info,            //记录的日志类型，info代表所有信息都记录
		IgnoreRecordNotFoundError: true,                   //是否忽略找不到数据错误信息（只是日志记录记录成err还是普通的输出的区别，并不影响业务代码中的：找不到数据行error）
		Colorful:                  false,                  //是否颜色输出
	})
	// 1. 连接到 SQLite 数据库
	// 如果数据库文件不存在，GORM 会自动创建一个新的数据库文件
	db, err := gorm.Open(sqlite.Open(sqliteConf.DbPath), &gorm.Config{
		Logger: newLogger,
	})
	if err != nil {
		log.Fatal("无法连接到数据库：", err)
	}
	global.SqliteDB = db
	initTable()
}

func initTable() {
	err := global.SqliteDB.AutoMigrate(&report.ListenReportLog{})
	if err != nil {
		log.Fatal("自动迁移失败：", err)
	}
}
