package report

import (
	"gn/gn_email_listen/global"
	"time"
)

// ListenReportLog 外部报告
type ListenReportLog struct {
	Id              uint      `gorm:"primaryKey;autoIncrement;column:id;type:integer" json:"-"`
	Title           string    `gorm:"column:title;type:varchar(100)" json:"title"`                  // 报告标题
	Author          string    `gorm:"column:author;type:varchar(50)" json:"author"`                 // 创建人姓名
	Email           string    `gorm:"column:email;type:varchar(100)" json:"email"`                  // 创建人邮箱
	EmailMessageUID int       `gorm:"column:email_message_uid;type:integer" json:"emailMessageUid"` // 该邮件在邮箱中的唯一id
	CreateTime      time.Time `gorm:"column:create_time;autoCreateTime" json:"createTime"`          // 创建时间
}

// TableName get sql table name.获取数据库表名
func (m *ListenReportLog) TableName() string {
	return "listen_report_log"
}

// OutsideReportColumns get sql column name.获取数据库列名
var OutsideReportColumns = struct {
	Id              string
	Title           string
	Author          string
	EmailMessageUID string
	CreateTime      string
}{
	Id:              "id",
	Title:           "title",
	Author:          "author",
	EmailMessageUID: "email_message_uid",
	CreateTime:      "create_time",
}

// GetListenReportLogByEmailMessageId
// @Description: 根据邮件id获取报告
// @author: Roc
// @datetime 2024-09-14 17:49:35
// @param emailMessageUid int
// @return item *OutsideReport
// @return err error
func GetListenReportLogByEmailMessageId(emailMessageUid int) (item *ListenReportLog, err error) {
	err = global.SqliteDB.Where("email_message_uid = ?", emailMessageUid).First(&item).Error
	return
}

// CreateListenReportLog
// @Description: 新增报告&附件
// @author: Roc
// @datetime 2024-09-14 16:23:41
// @param item *OutsideReport
// @return err error
func CreateListenReportLog(item *ListenReportLog) (err error) {
	db := global.SqliteDB.Begin()
	defer func() {
		if err != nil {
			db.Rollback()
		} else {
			db.Commit()
		}
	}()

	// 添加报告
	err = global.SqliteDB.Create(item).Error
	if err != nil {
		return
	}

	return

}

// GetMaxOutsideReportByEmailMessageId
// @Description: 获取最大的邮件id
// @return maxEmailMessageUid
// @return err
func GetMaxOutsideReportByEmailMessageId() (maxEmailMessageUid int, err error) {
	err = global.SqliteDB.Model(ListenReportLog{}).Select("COALESCE(MAX(email_message_uid), 0)").Find(&maxEmailMessageUid).Error
	return
}
