package services

import (
	"bytes"
	"encoding/json"
	"fmt"
	"gn/gn_email_listen/global"
	"io"
	"mime/multipart"
	"net/http"
)

type BaseResponse struct {
	Code   int         `json:"code" description:"状态码"`
	Msg    string      `json:"msg" description:"提示信息"`
	Data   interface{} `json:"data" description:"返回数据"`
	ErrMsg string      `json:"-" description:"错误信息，不用返回给前端，只是做日志记录"`
}

func SendFilesHttp(url string, files map[string][]byte, params map[string]string) (result BaseResponse, err error) {
	var requestBody bytes.Buffer
	writer := multipart.NewWriter(&requestBody)
	// 创建表单文件字段并将附件数据写入其中
	for fieldname, fileData := range files {
		part, er := writer.CreateFormFile(fieldname, fieldname)
		if er != nil {
			err = fmt.Errorf("无法创建文件表单字段: %v", er)
			return
		}
		if _, err = io.Copy(part, bytes.NewReader(fileData)); err != nil {
			return result, fmt.Errorf("无法写入文件数据: %v", err)
		}
	}
	for k, v := range params {
		writer.WriteField(k, v)
	}
	writer.Close()

	req, err := http.NewRequest("POST", url, &requestBody)
	if err != nil {
		global.FILE_LOG.Errorf("create request error: %v", err)
		return
	}

	// 设置请求头
	req.Header.Set("Content-Type", writer.FormDataContentType())
	client := &http.Client{}
	resp, err := client.Do(req)
	if err != nil {
		return
	}
	defer resp.Body.Close()
	if resp.StatusCode != http.StatusOK {
		err = fmt.Errorf("http status code error: %d", resp.StatusCode)
		return
	}

	body, err := io.ReadAll(resp.Body)
	if err != nil {
		return
	}
	if err = json.Unmarshal(body, &result); err != nil {
		return
	}
	return
}
